@@ -19,13 +19,14 @@ def get_stage():
         stage = "local"
     return stage
 
-def get_now_str(config):
 
+def get_now_str(config):
     time_format = config["time_format"]
     now = datetime.strftime(datetime.now(), time_format)
 
     return now
 
+
 def in_list(a, b):
     for item in a:
         if item in b:
@@ -34,20 +35,38 @@ def in_list(a, b):
             return False
     return True
 
+
+def validate_not_nullable(required, payload):
+    for i in required:
+        if i in payload:
+            if not payload[i]:
+                return False
+    return True
+
+
 def in_required_list(required, payload):
     for item in required:
-        if item in payload:
+        if item in payload and payload[item]:
             continue
         else:
             return False
     return True
 
+
+def in_allowed_list(allowed, payload):
+    for item in payload:
+        if item not in allowed:
+            return False
+    return True
+
+
 def if_empty(object):
     for key, value in object.items():
         if value == "" or value == [] or value == {}:
             return True
     return False
 
+
 def validate_str_input(payload):
     for key, value in payload.items():
         if not value:
@@ -57,6 +76,7 @@ def validate_str_input(payload):
                 return False
     return True
 
+
 def object_mapper(object, result):
     mapped_object = {}
     x = 0
@@ -67,6 +87,7 @@ def object_mapper(object, result):
 
     return mapped_object
 
+
 def is_json(object):
     try:
         json_object = json.loads(object)
@@ -78,7 +99,6 @@ def is_json(object):
 
 
 def is_list_of_jsons(payload):
-
     try:
         for item in payload:
             if is_json(json.dumps(item)) is True:
@@ -89,7 +109,8 @@ def is_list_of_jsons(payload):
     except:
         return False
 
-def make_instert_string(object, table): ## TO BE DELETED
+
+def make_instert_string(object, table):  ## TO BE DELETED
 
     fileds = ""
     values = ""
@@ -134,8 +155,8 @@ def make_instert_string(object, table): ## TO BE DELETED
 
     return insert_string
 
-def make_insert_string_v2(object, table_name, on_conflict):
 
+def make_insert_string_v2(object, table_name, on_conflict):
     fields = ""
     values = ""
 
@@ -190,9 +211,7 @@ def make_insert_string_v2(object, table_name, on_conflict):
     return insert_string
 
 
-
 def make_update_string(object, table, key, key_value):
-
     string = ""
 
     for name, value in object.items():
@@ -254,6 +273,10 @@ def make_update_string_v2(object, table, key, key_value):
                     value = json.dumps(value).replace("[", "{").replace("]", "}")
                     string = string + name + " = '" + value + "', "
 
+            elif type(value) is bool:
+
+                string += name + " = " + str(value) + ", "
+
             elif value is None:
                 string = string + name + " =  NULL, "
 
@@ -268,4 +291,4 @@ def make_update_string_v2(object, table, key, key_value):
     update_string = update_string.replace("'", "\'")
     print("UPDATE STRING: " + update_string)
 
-    return update_string
\ No newline at end of file
+    return update_string
